# cheeta-jwt

__Cheeta-JWT__ is a simple wrapper over the *pyjwt* library that makes the usage of it more easier. Also __Cheeta-JWT__ provides facilities to use it as a falcon middleware.


## How to install
```shell
pip install CheetaJWT
```

## How to use it


## How to test  
 

## How to contribute

If you like to contribute to this project, just fork it and submit your changes as pull requests.
